<?php 

namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;

class SelectAberturaCaixa extends CrudWithParameterBag {
    
    protected $dataSourceName = 'select_aberturacaixa'; 
    protected $parameterBagColumns = 
        array(
            'DTABERINI',
            'DTABERFIM',
            'TDTABERCAIX',
            'CDFILIAL',
            'TCDFILIAL',
            'CDFILILOJA',
            'TCDFILILOJA',
            'CDFILILOJACAIXA',
            'TCDFILILOJACAIXA',
            'TDTFECHCAIX',
            'NRORG');
    
    private function setTCDandCDcondition(&$conditions, $key, $keyName) {
        if( !array_key_exists($key, $conditions) ) {
            $conditions['T'.$keyName] = 'T';    
            $conditions[$keyName] = null;    
        } else {
            if(!empty($conditions[$key])) {
                $conditions[$keyName] = '_'.implode('_', $conditions[$keyName] ).'_';
            }
            $conditions['T'.$keyName] = 'F';
            if($key !== $keyName) {
                unset($conditions[$keyName]);
            }
        }
    }
    
    public function __construct($dataSourceManager, $parameterBag, $utilService ) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response ) {
        $conditions = $this->utilService->getParamsAsArray($request);
        if( (array_key_exists('CDFILIAL', $conditions)) &&
            (array_key_exists('CDFILILOJA', $conditions)) &&
            (array_key_exists('CDFILILOJACAIXA', $conditions)) ) {
        
            if($conditions['CDFILIAL'] === null) {
                unset($conditions['CDFILIAL']);
            }
            
            if($conditions['CDFILILOJA'] === null) {
                unset($conditions['CDFILILOJA']);
            }
            
            if($conditions['CDFILILOJACAIXA'] === null) {
                unset($conditions['CDFILILOJACAIXA']);
            }
            
            $this->setTCDandCDcondition($conditions, 'CDFILIAL', 'CDFILIAL');
            $this->setTCDandCDcondition($conditions, 'CDFILILOJA', 'CDFILILOJA');
            $this->setTCDandCDcondition($conditions, 'CDFILILOJACAIXA', 'CDFILILOJACAIXA');
            
            // If you use a different name than DTENTRVENDA, 
            // just copy this line and set yours condition name.
            // Or you could just use an Outdata for DTENTRVENDA.
            if( array_key_exists('DTENTRVENDA', $conditions) ) {
                $conditions['DTABERINI'] = $conditions['DTENTRVENDA']['start'];
                $conditions['DTABERFIM'] = $conditions['DTENTRVENDA']['end'];
                $conditions['TDTABERCAIX'] = 'F';
                unset($conditions['DTENTRVENDA']);
            } else {
                $conditions['TDTABERCAIX'] = 'T';
            } 
            
            $conditions['TDTFECHCAIX'] = !array_key_exists('TDTFECHCAIX', $conditions) ? 'T' : $conditions['TDTFECHCAIX'];
            
            $dataSourceFilter = [];
            
            foreach($conditions as $key => $value) {
                $dataSourceFilter[] = $condition = array(
                    "columnName" => $key,
                    "operator"=> "=",
                    "value"=> $value
                );
            }
            
            $newRequest = new DTO\Request\Filter (
                new FilterCriteria(
                    $request->getFilterCriteria()->getDataSourceName(),
                    $dataSourceFilter,
                    $request->getFilterCriteria()->getPage(),
                    $request->getFilterCriteria()->getPageSize()
                ),
                $request->getMethod(),
                $request->getRoutePath(),
                $request->getUserId()
            );
            
            parent::find($newRequest, $response);
        }
    }
}